OnCameraIdle typedef

OnCameraIdle = void Function(CameraPosition position)

Called when the camera movement has ended, there are no pending animations and the user has stopped interacting with the map.

position is the camera position where the motion ended.

Implementation

typedef OnCameraIdle = void Function(CameraPosition position);