OnCameraStoppedFollowingLocation typedef
OnCameraStoppedFollowingLocation =
void Function(CameraPosition position)
Called when the camera stops following current location. A camera already following location will exit the follow mode if the camera is moved via user gesture or an API call, e.g. GoogleNavigationViewController.moveCamera or GoogleNavigationViewController.animateCamera. Only applicable on Android.
position is the current camera position.
Implementation
typedef OnCameraStoppedFollowingLocation = void Function(
CameraPosition position);